
from setuptools import setup, find_packages

setup(
    name="mseep-mcp-rememberizer-vectordb",
    version="0.1.2",
    description="A Model Context Protocol server for interacting with Rememberizer Vector Store (https://docs.rememberizer.ai/developer/vector-stores).",
    author="mseep",
    author_email="support@skydeck.ai",
    url="",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=['httpx>=0.27.2', 'mcp>=1.0.0', 'python-dotenv>=1.0.1'],
    keywords=["mseep"] + [],
)
